BB.Error.Estimator.MissingCovariance exception (bb v0.20.0)

Copy Markdown View Source

An algorithm required a covariance field on an input payload but the upstream publisher left it nil.

Many Kalman-family algorithms cannot proceed without measurement noise. They may either fall back to a configured default or raise this error, depending on configuration.

Summary

Types

t()

@type t() :: %BB.Error.Estimator.MissingCovariance{
  __exception__: true,
  bread_crumbs: term(),
  class: term(),
  estimator: atom(),
  field: atom(),
  path: term(),
  splode: term(),
  stacktrace: term(),
  vars: term()
}

Functions

exception(args)

@spec exception(opts :: Keyword.t()) :: %BB.Error.Estimator.MissingCovariance{
  __exception__: true,
  bread_crumbs: term(),
  class: term(),
  estimator: term(),
  field: term(),
  path: term(),
  splode: term(),
  stacktrace: term(),
  vars: term()
}

Create an Elixir.BB.Error.Estimator.MissingCovariance without raising it.

Keys

  • :estimator
  • :field