Information about a currently executing command.
Tracks metadata for commands running in the robot runtime.
Summary
Types
@type t() :: %BB.Robot.CommandInfo{ category: atom(), name: atom(), pid: pid(), ref: reference(), started_at: DateTime.t() }
Information about a currently executing command.
Tracks metadata for commands running in the robot runtime.
@type t() :: %BB.Robot.CommandInfo{ category: atom(), name: atom(), pid: pid(), ref: reference(), started_at: DateTime.t() }